pub fn contains_aggregate(expr: &Expr, functions: &FunctionRegistry) -> boolExpand description
Return true if any aggregate function call appears anywhere inside
expr — at any nesting depth, inside any expression position.
pub fn contains_aggregate(expr: &Expr, functions: &FunctionRegistry) -> boolReturn true if any aggregate function call appears anywhere inside
expr — at any nesting depth, inside any expression position.