pub fn resolve_engine_rules(engine: EngineType) -> &'static dyn EngineRulesExpand description
Resolve the engine rules for a given engine type.
No catch-all — compiler enforces exhaustiveness.
pub fn resolve_engine_rules(engine: EngineType) -> &'static dyn EngineRulesResolve the engine rules for a given engine type.
No catch-all — compiler enforces exhaustiveness.