parse_phrase_terms

Function parse_phrase_terms 

pub fn parse_phrase_terms(input: &str) -> FtsQuery
Build an FtsQuery::Phrase from whitespace-separated terms.

Used by phraseto_tsquery. The resulting variant is always rejected by the executor with Unsupported — it is only produced so that the error path is reached correctly.