Module type_expr

Module type_expr 

Parser and validator for type expression strings used by the typeguard system.

Parses strings like "STRING", "INT|NULL", "ARRAY<STRING>" into a TypeExpr that can be used to validate nodedb_types::Value instances at write time.

Enums

SimpleType
Leaf type variants that map to a single Value discriminant.
TypeExpr
A parsed type expression that can validate Values.

Functions

parse_type_expr
Parse a type expression string into a TypeExpr.
value_matches_type
Check if a Value matches a TypeExpr.