Module correlation

Module correlation 

Extract correlation predicates from a LATERAL subquery’s WHERE clause.

A correlated predicate is one where the left side references the outer table and the right side references the inner table (or vice versa). The outer table is identified by its alias or name.

Structs

CorrelationAnalysis
Result of analysing a lateral subquery’s WHERE clause.
CorrelationEq
A single equi-correlation pair extracted from the subquery WHERE.

Functions

analyse_lateral_where
Analyse the WHERE clause of a LATERAL subquery.