Parser and validator for type expression strings used by the typeguard system.
Parses strings like "STRING", "INT|NULL", "ARRAY<STRING>" into a
TypeExpr that can be used to validate nodedb_types::Value instances
at write time.
Enums
- Simple
Type - Leaf type variants that map to a single Value discriminant.
- Type
Expr - A parsed type expression that can validate Values.
Functions
- parse_
type_ expr - Parse a type expression string into a
TypeExpr. - value_
matches_ type - Check if a
Valuematches aTypeExpr.